@@ -141,14 +141,13 @@ atk_image_set_image_description (AtkImage        *image,
 /**
  * atk_image_get_image_position:
  * @image: a #GObject instance that implements AtkImageIface
- * @x: address of #gint to put x coordinate position
- * @y: address of #gint to put y coordinate position
+ * @x: address of #gint to put x coordinate position; otherwise, -1 if value cannot be obtained.
+ * @y: address of #gint to put y coordinate position; otherwise, -1 if value cannot be obtained.
  * @coord_type: specifies whether the coordinates are relative to the screen
  * or to the components top level window
  * 
  * Gets the position of the image in the form of a point specifying the
- * images top-left corner.  The values of @x and @y are returned as -1
- * if the values cannot be obtained.
+ * images top-left corner.
  **/
 void     
 atk_image_get_image_position (AtkImage *image,
@@ -187,3 +186,27 @@ atk_image_get_image_position (AtkImage *image,
     *y = -1;
   }
 }
+
+/** 
+ * Returns a string corresponding to the POSIX LC_MESSAGES locale used by the image description, or NULL if the image does not specify a locale. 
+ * @Since ATK 1.12
+ */
+G_CONST_RETURN gchar* 
+atk_image_get_image_locale (AtkImage   *image)
+{
+	
+  AtkImageIface *iface;
+
+  g_return_val_if_fail (ATK_IS_IMAGE (image), NULL);
+
+  iface = ATK_IMAGE_GET_IFACE (image);
+
+  if (iface->get_image_locale)
+    {
+      return (iface->get_image_locale) (image);
+    }
+  else
+    {
+      return NULL;
+    }
+}
